@@ -45,7 +45,14 @@ enum n_coeffType
   n_Znm, /**< only used if HAVE_RINGS is defined */
   n_Z2m, /**< only used if HAVE_RINGS is defined */
   n_FlintQrat, /**< rational funtion field over Q */
-  n_CF /**< ? */
+  n_CF, /**< ? */
+  n_Nemo_AnticNumberField, /*17 */
+  n_Nemo_QQField,          /*18 */
+  n_Nemo_ZZRing,           /*19*/
+  n_Nemo_FqPolyRepField,   /*20 */
+  n_Nemo_fqPolyRepField,   /*21 */
+  n_Nemo_Field,            /*22 */
+  n_Nemo_Ring              /*23 */
 };
 
 extern const unsigned short fftable[];
@@ -130,7 +137,7 @@ struct n_Procs_s
    int     factoryVarOffset;
 
    // general properties:
-   /// TRUE, if nNew/nDelete/nCopy are dummies
+   /// TRUE, if nDelete/nCopy are dummies
    BOOLEAN has_simple_Alloc;
    /// TRUE, if std should make polynomials monic (if nInvers is cheap)
    /// if false, then a gcd routine is used for a content computation
@@ -377,7 +384,8 @@ struct n_Procs_s
    int     (*cfDivComp)(number a,number b,const coeffs r);
    BOOLEAN (*cfIsUnit)(number a,const coeffs r);
    number  (*cfGetUnit)(number a,const coeffs r);
-   //CF: test if b divides a
+   /// test if b divides a
+   /// cfDivBy(zero,b,r) is true, if b is a zero divisor
    BOOLEAN (*cfDivBy)(number a, number b, const coeffs r);
   /* The following members are for representing the ring Z/n,
      where n is not a prime. We distinguish four cases:
@@ -436,10 +444,6 @@ void nKillChar(coeffs r);
 static FORCE_INLINE void nSetChar(const coeffs r)
 { assume(r!=NULL); assume(r->cfSetChar != NULL); r->cfSetChar(r); }
 
-void           nNew(number * a);
-#define n_New(n, r)           nNew(n)
-
-
 /// Return the characteristic of the coeff. domain.
 static FORCE_INLINE int n_GetChar(const coeffs r)
 { assume(r != NULL); return r->ch; }
@@ -902,7 +906,7 @@ static FORCE_INLINE BOOLEAN nCoeff_is_CF(const coeffs r)
 static FORCE_INLINE BOOLEAN nCoeff_has_simple_inverse(const coeffs r)
 { assume(r != NULL); return r->has_simple_Inverse; }
 
-/// TRUE if n_Delete/n_New are empty operations
+/// TRUE if n_Delete is empty operation
 static FORCE_INLINE BOOLEAN nCoeff_has_simple_Alloc(const coeffs r)
 { assume(r != NULL); return r->has_simple_Alloc; }
 
