@@ -17,7 +17,7 @@ typedef BOOLEAN (*s_poly_proc_t)(kStrategy strat);
 #define KSTD_NF_LAZY   1
   // do only a reduction of the leading term
 #define KSTD_NF_ECART  2
-  // only local: recude even with bad ecart
+  // only local: reduce even with bad ecart
 #define KSTD_NF_NONORM 4
   // only global: avoid normalization, return a multiply of NF
 
@@ -29,6 +29,7 @@ ideal kNF(ideal F, ideal Q, ideal p,int syzComp=0, int lazyReduce=0);
 
 poly kNFBound (ideal F, ideal Q, poly p,int bound,int syzComp=0, int lazyReduce=0);
 ideal kNFBound (ideal F, ideal Q, ideal p,int bound,int syzComp=0, int lazyReduce=0);
+ideal idDivRem(ideal A, const ideal quot, ideal &factor,ideal *unit,int lazyReduce=0);
 
 /// NOTE: this is just a wrapper which sets currRing for the actual kNF call
 poly k_NF (ideal F, ideal Q, poly p,int syzComp, int lazyReduce, const ring _currRing);
@@ -41,29 +42,30 @@ ideal kStd(ideal F, ideal Q, tHomog h, intvec ** mw,intvec *hilb=NULL,
 ideal kStdShift(ideal F, ideal Q, tHomog h,intvec ** mw, intvec *hilb=NULL,
     int syzComp=0, int newIdeal=0, intvec *vw=NULL, BOOLEAN rightGB=FALSE);
 
-ideal rightgb(ideal F, ideal Q);
+ideal rightgb(ideal F,const ideal Q);
 
 /* the following global data are defined in kutil.cc */
 //extern int syzComp;
   /*stop building pairs after that component --> ideals.cc, syz.cc */
-EXTERN_VAR int LazyPass,LazyDegree,Kstd1_mu,Kstd1_deg;
-  /*parameters for Lazy or global stops --> ipshell.cc, grammar.y*/
+EXTERN_VAR int Kstd1_mu,Kstd1_deg;
+  /*parameters for global stops --> ipshell.cc, grammar.y*/
 EXTERN_VAR BITSET kOptions;
   /*the known test options (a constant)*/
 EXTERN_VAR BITSET validOpts;
 
 void initMora(ideal F,kStrategy strat);
 
-ideal kInterRed (ideal F, ideal Q=NULL);
-ideal kInterRedOld (ideal F, ideal Q=NULL);
-long   kModDeg(poly p, ring r = currRing);
-long  kHomModDeg(poly p, ring r = currRing);
+ideal kInterRed (ideal F, const ideal Q=NULL);
+ideal kInterRedOld (ideal F, const ideal Q=NULL);
+long   kModDeg(poly p, const ring r = currRing);
+long  kHomModDeg(poly p, const ring r = currRing);
 
 ideal stdred(ideal F, ideal Q, tHomog h,intvec ** w);
 
 ideal kMin_std(ideal F, ideal Q, tHomog h,intvec ** w, ideal &M,
               intvec *hilb=NULL, int syzComp=0,int reduced=0);
 
+BOOLEAN kVerify(ideal F,ideal Q);
 
 EXTERN_VAR intvec * kModW;
 EXTERN_VAR intvec * kHomW;
